[PATCH] D33593: [mips] Don't use FastISel when -mxgot is present

Stefan Maksimovic via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed May 31 05:54:40 PDT 2017


smaksimovic updated this revision to Diff 100853.
smaksimovic added a comment.

Comment updated.


https://reviews.llvm.org/D33593

Files:
  lib/Target/Mips/MipsISelLowering.cpp
  test/CodeGen/Mips/biggot.ll


Index: test/CodeGen/Mips/biggot.ll
===================================================================
--- test/CodeGen/Mips/biggot.ll
+++ test/CodeGen/Mips/biggot.ll
@@ -1,6 +1,9 @@
 ; RUN: llc -march=mipsel -mxgot -relocation-model=pic < %s | FileCheck %s -check-prefix=O32
 ; RUN: llc -march=mips64el -mcpu=mips64r2 -mxgot -relocation-model=pic < %s | \
 ; RUN: FileCheck %s -check-prefix=N64
+; RUN: llc -march=mipsel -mxgot -relocation-model=pic -fast-isel < %s | FileCheck %s -check-prefix=O32
+; RUN: llc -march=mips64el -mcpu=mips64r2 -mxgot -relocation-model=pic -fast-isel < %s | \
+; RUN: FileCheck %s -check-prefix=N64
 
 @v0 = external global i32
 
Index: lib/Target/Mips/MipsISelLowering.cpp
===================================================================
--- lib/Target/Mips/MipsISelLowering.cpp
+++ lib/Target/Mips/MipsISelLowering.cpp
@@ -471,8 +471,9 @@
                      !Subtarget.hasMips32r6() && !Subtarget.inMips16Mode() &&
                      !Subtarget.inMicroMipsMode();
 
-  // Disable if we don't generate PIC or the ABI isn't O32.
-  if (!TM.isPositionIndependent() || !TM.getABI().IsO32())
+  // Disable if either of the following is true:
+  // We don't generate PIC, the ABI isn't O32, LargeGOT is being used.
+  if (!TM.isPositionIndependent() || !TM.getABI().IsO32() || LargeGOT)
     UseFastISel = false;
 
   return UseFastISel ? Mips::createFastISel(funcInfo, libInfo) : nullptr;


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D33593.100853.patch
Type: text/x-patch
Size: 1427 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20170531/5406d003/attachment.bin>


More information about the llvm-commits mailing list